==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-es-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: es\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: "Llamar"

, "Calls"
: "Llamadas"

, "Line"
: "Línea"

, "Caller Id"
: "Identificador de la Llamada"

, "Start"
: "Comenzar"

, "Connected"
: "Conectado"

, "Disconnected"
: "Desconectado"

, "Duration"
: "Duración"

, "Ringing"
: "Timbrando"

, "Direction"
: "Orientación"

, "Source"
: "Fuente"

, "Destination"
: "Destino"

, "Phone"
: "Teléfono"

, "Phones"
: "Teléfonos"

, "Settings"
: "Configuración"

, "Lines"
: "Lineas"

, "Description"
: "Descripción"

, "Number"
: "Número"

, "Cancel"
: "Cancelar"

, "Dial"
: "Marcar"

, "Error"
: "Error"

, "Not possible to dial."
: "Fue imposible discar."

, "Edit phone settings"
: "Editar preferencias del teléfono"

, "Dial number"
: "Número de discado"

, "Initiate a new outgoing call"
: "Comenzar una nueva llamada de salida"

, "No phone selected"
: "Teléfono no seleccionado"

, "Please select the desired phone in the tree!"
: "Seleccione teléfono"

, "Call contact"
: "Llamar a contacto"

, "Work"
: "Trabajo"

, "Home"
: "Casa"

, "Cell"
: "Móvil"

, "Cell private"
: "Móvil privado"

, "Incoming call"
: "Llamada entrante"

, "Outgoing call"
: "Llamada de salida"

, "unknown number"
: "número desconocido"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: "Llamadas esta semana"

, "Incoming and outgoing calls of this week"
: "Llamadas entrantes/salientes esta semana"

, "Calls last week"
: "Llamadas última semana"

, "Incoming and outgoing calls of last week"
: "Llamadas entrantes/salientes última semana"

, "Calls this month"
: "Llamadas este mes"

, "Incoming and outgoing calls of this month"
: "Llamadas entrantes/salientes este mes"

, "Calls last month"
: "Llamadas último mes"

, "Incoming and outgoing calls of last month"
: "Llamadas entrantes/salientes último mes"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.03.4.tar.bz2: Phone/js/Phone-lang-es-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Llamada entrante"

, "Outgoing call"
: "Llamada de salida"

, "unknown number"
: "número desconocido"

, "Phone"
: "Teléfono"

, "Line"
: "Línea"

, "Number"
: "Número"

, "Cancel"
: "Cancelar"

, "Dial"
: "Marcar"

, "Error"
: "Error"

, "Not possible to dial."
: "Fue imposible discar."

, "Call contact"
: "Llamar a contacto"

, "Work"
: "Trabajo"

, "Home"
: "Casa"

, "Cell"
: "Móvil"

, "Cell private"
: "Móvil privado"

, "Edit phone settings"
: "Editar preferencias del teléfono"

, "Dial number"
: "Número de discado"

, "Initiate a new outgoing call"
: "Comenzar una nueva llamada de salida"

, "Phones"
: "Teléfonos"

, "No phone selected"
: "Teléfono no seleccionado"

, "Please select the desired phone in the tree!"
: "Seleccione teléfono"

, "Calls this week"
: "Llamadas esta semana"

, "Calls last week"
: "Llamadas última semana"

, "Calls this month"
: "Llamadas este mes"

, "Calls last month"
: "Llamadas último mes"

, "Incoming and outgoing calls of this week"
: "Llamadas entrantes/salientes esta semana"

, "Incoming and outgoing calls of last week"
: "Llamadas entrantes/salientes última semana"

, "Incoming and outgoing calls of this month"
: "Llamadas entrantes/salientes este mes"

, "Incoming and outgoing calls of last month"
: "Llamadas entrantes/salientes último mes"

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: "Llamar"

, "Calls"
: "Llamadas"

, "Caller Id"
: "Identificador de la Llamada"

, "Start"
: "Comenzar"

, "Connected"
: "Conectado"

, "Disconnected"
: "Desconectado"

, "Duration"
: "Duración"

, "Ringing"
: "Timbrando"

, "Direction"
: "Orientación"

, "Source"
: "Fuente"

, "Destination"
: "Destino"

, "resolved destination"
: ""

, "Settings"
: "Configuración"

, "Lines"
: "Lineas"

, "Description"
: "Descripción"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
